# qucs2gerber Package

This is a tool that generates Gerber code from a Qucs schematic file.

Example Qucs schematic:
![Qucs Example](/images/qucs_example.png)
Format: ![Qucs Example](url)

Example qucs2gerber usage:
**python -m qucs2gerber -s demo.sch -o output.grb**

Gerber file generated:
![Gerber Example](/images/gerber_example.png)

